Changelog
=========

Version 0.1.5 (2023-06-16)
--------------------------

* Added `OMinMax` class for calculation of minimum, maximum and number of points.

Version 0.1.4 (2023-05-07)
--------------------------

* Added `OReg` class for handling an univariate regression.
* Added convenience method `of_frame` for quick computation of pandas dataframes.
* Explicit `compute` override to play well with intellisense.

Version 0.1.3 (2023-01-21)
--------------------------

* Fix for `of_groupby` methods with no weights.
* Added convenience methods for accessing members in lambda functions.

Version 0.1.2 (2022-11-28)
--------------------------

* Explicit handling of invalid values (drop, keep, raise).
* Separation of initialization and calculation.
* Benchmarking vs RunStats.

Version 0.1.1 (2022-11-01)
--------------------------

Version 0.1.0 (2022-10-30)
--------------------------

* Initial release
